from setuptools import setup

setup(
    name='py-protocol',
    version='0.0.3a3',
    description= 'Support for network protocol senders',
    long_description='',
    author='Phuc Bao',
    packages=['protocol'],
)